declare interface IEditEntrySearchParams {
    hash?: string;
    entry_uid?: string;
    content_type_uid?: string;
    /**
     * @deprecated pass this value as hash instead
     */
    live_preview?: string;
}
declare interface IClientUrlParams {
    protocol: "http" | "https";
    host: string;
    port: string | number;
    url: string;
}
declare interface IStackSdk {
    live_preview: {
        [key: string]: any;
    } & Partial<IConfig>;
    [key: string]: any;
    headers: {
        api_key: string;
    };
    environment: string;
}
declare interface IStackDetails {
    apiKey: string;
    environment: string;
    branch: string;
    contentTypeUid: string;
    entryUid: string;
}
declare interface IInitStackDetails {
    apiKey: string;
    environment: string;
    branch: string;
}
declare interface IConfig {
    ssr: boolean;
    enable: boolean;
    cleanCslpOnProduction: boolean;
    stackDetails: IStackDetails;
    clientUrlParams: IClientUrlParams;
    stackSdk: IStackSdk;
    onChange: () => void;
    runScriptsOnUpdate: boolean;
    hash: string;
    editButton: IConfigEditButton;
}
declare interface IConfigEditButton {
    enable: boolean;
    exclude?: ("insideLivePreviewPortal" | "outsideLivePreviewPortal")[];
    includeByQueryParameter?: boolean;
    position?: "top" | "bottom" | "left" | "right" | "top-left" | "top-right" | "top-center" | "bottom-left" | "bottom-right" | "bottom-center";
}
declare interface IInitData {
    ssr: boolean;
    runScriptsOnUpdate: boolean;
    enable: boolean;
    cleanCslpOnProduction: boolean;
    stackDetails: Partial<IInitStackDetails>;
    clientUrlParams: Partial<Omit<IClientUrlParams, "url">>;
    stackSdk: IStackSdk;
    editButton: IConfigEditButton;
}
declare interface ILivePreviewMessageCommon {
    from: "live-preview";
}
type ILivePreviewReceivePostMessages = IClientDataMessage | IInitAckMessage | IHistoryMessage;
declare interface IClientDataMessage extends ILivePreviewMessageCommon {
    type: "client-data-send";
    data: {
        hash: string;
    };
}
declare interface IInitAckMessage extends ILivePreviewMessageCommon {
    type: "init-ack";
    data: {
        contentTypeUid: string;
        entryUid: string;
    };
}
declare interface IHistoryMessage extends ILivePreviewMessageCommon {
    type: "history";
    data: {
        type: "forward" | "backward" | "reload";
    };
}
declare interface IEditButtonPosition {
    upperBoundOfTooltip: number;
    leftBoundOfTooltip: number;
}
declare type OnEntryChangeCallback = () => void;
declare type OnEntryChangeConfig = {
    skipInitialRender?: boolean;
};
declare type OnEntryChangeCallbackUID = string;

export type { IClientDataMessage, IClientUrlParams, IConfig, IConfigEditButton, IEditButtonPosition, IEditEntrySearchParams, IHistoryMessage, IInitAckMessage, IInitData, IInitStackDetails, ILivePreviewMessageCommon, ILivePreviewReceivePostMessages, IStackDetails, IStackSdk, OnEntryChangeCallback, OnEntryChangeCallbackUID, OnEntryChangeConfig };
