"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/contentstack-live-preview-HOC.ts
var contentstack_live_preview_HOC_exports = {};
__export(contentstack_live_preview_HOC_exports, {
  default: () => contentstack_live_preview_HOC_default
});
module.exports = __toCommonJS(contentstack_live_preview_HOC_exports);
var import_uuid = require("uuid");
var import_camelCase = __toESM(require("./utils/camelCase.cjs"), 1);
var import_live_preview = __toESM(require("./live-preview.cjs"), 1);
var import_defaults = require("./utils/defaults.cjs");
var import_public_logger = require("./utils/public-logger.cjs");
var import_compare = require("./compare.cjs");
var import_handlePageTraversal = require("./utils/handlePageTraversal.cjs");
var ContentstackLivePreview = {
  livePreview: null,
  userConfig: null,
  subscribers: {},
  configs: {
    params: {}
  },
  init(userConfig = import_defaults.userInitData) {
    if (typeof window !== "undefined") {
      if (ContentstackLivePreview.livePreview) {
        import_public_logger.PublicLogger.warn(
          "You have already initialized the Live Preview SDK. So, any subsequent initialization returns the existing SDK instance."
        );
        return Promise.resolve(ContentstackLivePreview.livePreview);
      } else {
        (0, import_compare.handleWebCompare)();
        (0, import_handlePageTraversal.handlePageTraversal)();
        ContentstackLivePreview.livePreview = new import_live_preview.default(
          userConfig
        );
        ContentstackLivePreview.livePreview.setOnChangeCallback(
          ContentstackLivePreview.publish
        );
        ContentstackLivePreview.livePreview.setConfigFromParams(
          ContentstackLivePreview.configs.params
        );
        ContentstackLivePreview.configs.params = {};
        return Promise.resolve(ContentstackLivePreview.livePreview);
      }
    } else {
      ContentstackLivePreview.userConfig = userConfig;
    }
  },
  get hash() {
    if (!ContentstackLivePreview.livePreview) {
      const urlParams = new URLSearchParams(
        ContentstackLivePreview.configs.params
      );
      return urlParams.get("live_preview") ?? "";
    }
    return ContentstackLivePreview.livePreview.hash;
  },
  /**
   * Sets the live preview hash from the query param which is
   * accessible via `hash` property.
   * @param params query param in an object form
   */
  setConfigFromParams(params = {}) {
    if (!ContentstackLivePreview.livePreview) {
      ContentstackLivePreview.configs.params = params;
      return;
    }
    ContentstackLivePreview.livePreview.setConfigFromParams(params);
  },
  publish() {
    Object.values(
      ContentstackLivePreview.subscribers
    ).forEach((func) => {
      func();
    });
  },
  subscribe(callback) {
    const callbackUid = (0, import_uuid.v4)();
    ContentstackLivePreview.subscribers[callbackUid] = callback;
    return callbackUid;
  },
  /**
   * @type {function}
   * @param onChangeCallback A function param to fetch the data from contentstack database
   * @param config An optional object param, pass {skipInitialRender:Boolean} to skip init call to onChangeCallback
   * @returns Subscribed Callback UID
   */
  onEntryChange(onChangeCallback, config) {
    const { skipInitialRender = false } = config || {};
    if (ContentstackLivePreview.userConfig) {
      ContentstackLivePreview.livePreview = new import_live_preview.default(
        ContentstackLivePreview.userConfig
      );
      ContentstackLivePreview.livePreview.setOnChangeCallback(
        ContentstackLivePreview.publish
      );
      ContentstackLivePreview.livePreview.setConfigFromParams(
        ContentstackLivePreview.configs.params
      );
      ContentstackLivePreview.configs.params = {};
      ContentstackLivePreview.userConfig = null;
    }
    const callbackUid = ContentstackLivePreview.subscribe(onChangeCallback);
    if (!skipInitialRender) {
      onChangeCallback();
    }
    return callbackUid;
  },
  /**
   * @type {function}
   * @param onChangeCallback A function param to fetch the data from contentstack database on content change.
   * @returns Subscribed Callback UID
   */
  onLiveEdit(onChangeCallback) {
    return ContentstackLivePreview.onEntryChange(onChangeCallback, {
      skipInitialRender: true
    });
  },
  unsubscribeOnEntryChange(callback) {
    if (typeof callback === "string") {
      if (!ContentstackLivePreview.subscribers[callback]) {
        import_public_logger.PublicLogger.warn("No subscriber found with the given id.");
      }
      delete ContentstackLivePreview.subscribers[callback];
    } else if (typeof callback === "function") {
      const isCallbackDeleted = Object.entries(
        ContentstackLivePreview.subscribers
      ).some(([uid, func]) => {
        if (func === callback) {
          delete ContentstackLivePreview.subscribers[uid];
          return true;
        }
        return false;
      });
      if (!isCallbackDeleted) {
        import_public_logger.PublicLogger.warn(
          "No subscriber found with the given callback."
        );
      }
    }
  },
  async getGatsbyDataFormat(sdkQuery, prefix) {
    if (typeof sdkQuery.find === "function") {
      return sdkQuery.toJSON().find().then((result) => {
        return result.map((res) => {
          return res.map((entry) => {
            const dataTitle = (0, import_camelCase.default)(
              `${prefix}_${sdkQuery.content_type_uid}`
            );
            return { [dataTitle]: entry };
          });
        });
      }).catch((err) => {
        console.error(err);
      });
    } else if (typeof sdkQuery.fetch === "function") {
      return sdkQuery.toJSON().fetch().then((ent) => {
        const dataTitle = (0, import_camelCase.default)(
          `${prefix}_${sdkQuery.content_type_uid}`
        );
        const entry = { [dataTitle]: ent };
        return entry;
      }).catch((err) => {
        console.error(err);
      });
    }
  },
  getSdkVersion() {
    return "2.0.0";
  }
};
var contentstack_live_preview_HOC_default = ContentstackLivePreview;
//# sourceMappingURL=contentstack-live-preview-HOC.cjs.map